@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import print_function
 
 url = "ldap://localhost:1390"
 base = "dc=stroeder,dc=de"
@@ -41,20 +42,20 @@ msgid = l.search_ext(
 pages = 0
 while True:
     pages += 1
-    print '-'*60
-    print "Getting page %d" % (pages)
+    print('-'*60)
+    print("Getting page %d" % (pages))
     rtype, rdata, rmsgid, serverctrls = l.result3(msgid,resp_ctrl_classes=known_ldap_resp_ctrls)
-    print '%d results' % len(rdata)
-    print 'serverctrls=',pprint.pprint(serverctrls)
-    print 'rdata=',pprint.pprint(rdata)
+    print('%d results' % len(rdata))
+    print('serverctrls=',pprint.pprint(serverctrls))
+    print('rdata=',pprint.pprint(rdata))
     pctrls = [
       c
       for c in serverctrls
       if c.controlType == SimplePagedResultsControl.controlType
     ]
     if pctrls:
-        print 'pctrls[0].size',repr(pctrls[0].size)
-        print 'pctrls[0].cookie',repr(pctrls[0].cookie)
+        print('pctrls[0].size',repr(pctrls[0].size))
+        print('pctrls[0].cookie',repr(pctrls[0].cookie))
         if pctrls[0].cookie:
             # Copy cookie from response control to request control
             req_ctrl.cookie = pctrls[0].cookie
@@ -68,7 +69,7 @@ while True:
         else:
             break
     else:
-        print "Warning:  Server ignores RFC 2696 control."
+        print("Warning:  Server ignores RFC 2696 control.")
         break
 
 l.unbind_s()
