@@ -2,11 +2,9 @@
 Demo for using ldap.resiter.ResultProcessor
 written by Michael Stroeder <michael@stroeder.com>
 
-See http://www.python-ldap.org for details.
-
-Python compability note:
-Requires Python 2.3+
+See https://www.python-ldap.org for details.
 """
+from __future__ import print_function
 
 import ldap,ldap.resiter
 
@@ -19,6 +17,6 @@ msgid = l.search('dc=stroeder,dc=de',ldap.SCOPE_SUBTREE,'(cn=m*)')
 
 result_iter = l.allresults(msgid)
 for result_type,result_list,result_msgid,result_serverctrls in result_iter:
-  print result_type,result_list,result_msgid,result_serverctrls
+  print(result_type,result_list,result_msgid,result_serverctrls)
 
 l.unbind_s()
