@@ -8,11 +8,25 @@ See https://www.python-ldap.org/ for details.
 
 from ldap.pkginfo import __version__, __author__, __license__
 
+import os
 import sys
 
 if __debug__:
   # Tracing is only supported in debugging mode
+  import atexit
   import traceback
+  _trace_level = int(os.environ.get("PYTHON_LDAP_TRACE_LEVEL", 0))
+  _trace_file = os.environ.get("PYTHON_LDAP_TRACE_FILE")
+  if _trace_file is None:
+    _trace_file = sys.stderr
+  else:
+    _trace_file = open(_trace_file, 'a')
+    atexit.register(_trace_file.close)
+  _trace_stack_limit = None
+else:
+  # Any use of the _trace attributes should be guarded by `if __debug__`,
+  # so they should not be needed here.
+  # But, providing different API for debug mode is unnecessarily fragile.
   _trace_level = 0
   _trace_file = sys.stderr
   _trace_stack_limit = None
@@ -84,7 +98,7 @@ class LDAPLock:
 # Create module-wide lock for serializing all calls into underlying LDAP lib
 _ldap_module_lock = LDAPLock(desc='Module wide')
 
-from ldap.functions import open,initialize,init,get_option,set_option,escape_str,strf_secs,strp_secs
+from ldap.functions import initialize,get_option,set_option,escape_str,strf_secs,strp_secs
 
 from ldap.ldapobject import NO_UNIQUE_ENTRY, LDAPBytesWarning
 
