@@ -4,28 +4,23 @@ schema.py - support for subSchemaSubEntry information
 See https://www.python-ldap.org/ for details.
 """
 
-import UserDict,ldap.cidict
+import sys
+
+import ldap.cidict
+from ldap.compat import IterableUserDict
 
 from ldap.schema.tokenizer import split_tokens,extract_tokens
 
-if __debug__:
-  from types import TupleType,StringType,IntType
-  try:
-    from types import BooleanType
-  except ImportError:
-    BooleanType = IntType
-
-
 NOT_HUMAN_READABLE_LDAP_SYNTAXES = {
-  '1.3.6.1.4.1.1466.115.121.1.4':None,  # Audio
-  '1.3.6.1.4.1.1466.115.121.1.5':None,  # Binary
-  '1.3.6.1.4.1.1466.115.121.1.8':None,  # Certificate
-  '1.3.6.1.4.1.1466.115.121.1.9':None,  # Certificate List
-  '1.3.6.1.4.1.1466.115.121.1.10':None, # Certificate Pair
-  '1.3.6.1.4.1.1466.115.121.1.23':None, # G3 FAX
-  '1.3.6.1.4.1.1466.115.121.1.28':None, # JPEG
-  '1.3.6.1.4.1.1466.115.121.1.40':None, # Octet String
-  '1.3.6.1.4.1.1466.115.121.1.49':None, # Supported Algorithm
+  '1.3.6.1.4.1.1466.115.121.1.4',  # Audio
+  '1.3.6.1.4.1.1466.115.121.1.5',  # Binary
+  '1.3.6.1.4.1.1466.115.121.1.8',  # Certificate
+  '1.3.6.1.4.1.1466.115.121.1.9',  # Certificate List
+  '1.3.6.1.4.1.1466.115.121.1.10', # Certificate Pair
+  '1.3.6.1.4.1.1466.115.121.1.23', # G3 FAX
+  '1.3.6.1.4.1.1466.115.121.1.28', # JPEG
+  '1.3.6.1.4.1.1466.115.121.1.40', # Octet String
+  '1.3.6.1.4.1.1466.115.121.1.49', # Supported Algorithm
 }
 
 
@@ -37,6 +32,7 @@ class SchemaElement:
 
   schema_element_str
     String which contains the schema element description to be parsed.
+    (Bytestrings are decoded using UTF-8)
 
   Class attributes:
 
@@ -51,6 +47,8 @@ class SchemaElement:
   }
 
   def __init__(self,schema_element_str=None):
+    if sys.version_info >= (3, 0) and isinstance(schema_element_str, bytes):
+      schema_element_str = schema_element_str.decode('utf-8')
     if schema_element_str:
       l = split_tokens(schema_element_str)
       self.set_id(l[1])
@@ -68,7 +66,7 @@ class SchemaElement:
     return self.oid
 
   def key_attr(self,key,value,quoted=0):
-    assert value is None or type(value)==StringType,TypeError("value has to be of StringType, was %s" % repr(value))
+    assert value is None or type(value)==str,TypeError("value has to be of str, was %r" % value)
     if value:
       if quoted:
         return " %s '%s'" % (key,value.replace("'","\\'"))
@@ -78,7 +76,7 @@ class SchemaElement:
       return ""
 
   def key_list(self,key,values,sep=' ',quoted=0):
-    assert type(values)==TupleType,TypeError("values has to be of ListType")
+    assert type(values)==tuple,TypeError("values has to be a tuple, was %r" % values)
     if not values:
       return ''
     if quoted:
@@ -108,28 +106,34 @@ class ObjectClass(SchemaElement):
   oid
     OID assigned to the object class
   names
-    This list of strings contains all NAMEs of the object class
+    All NAMEs of the object class (tuple of strings)
   desc
-    This string contains description text (DESC) of the object class
+    Description text (DESC) of the object class (string, or None if missing)
   obsolete
     Integer flag (0 or 1) indicating whether the object class is marked
     as OBSOLETE in the schema
   must
-    This list of strings contains NAMEs or OIDs of all attributes
-    an entry of the object class must have
+    NAMEs or OIDs of all attributes an entry of the object class must have
+    (tuple of strings)
   may
-    This list of strings contains NAMEs or OIDs of additional attributes
-    an entry of the object class may have
+    NAMEs or OIDs of additional attributes an entry of the object class may
+    have (tuple of strings)
   kind
     Kind of an object class:
     0 = STRUCTURAL,
     1 = ABSTRACT,
     2 = AUXILIARY
   sup
-    This list of strings contains NAMEs or OIDs of object classes
-    this object class is derived from
+    NAMEs or OIDs of object classes this object class is derived from
+    (tuple of strings)
+  x_origin
+    Value of the X-ORIGIN extension flag (tuple of strings)
+
+    Although it's not official, X-ORIGIN is used in several LDAP server
+    implementations to indicate the source of the associated schema
+    element
   """
-  schema_attribute = 'objectClasses'
+  schema_attribute = u'objectClasses'
   token_defaults = {
     'NAME':(()),
     'DESC':(None,),
@@ -139,7 +143,8 @@ class ObjectClass(SchemaElement):
     'AUXILIARY':None,
     'ABSTRACT':None,
     'MUST':(()),
-    'MAY':()
+    'MAY':(),
+    'X-ORIGIN':()
   }
 
   def _set_attrs(self,l,d):
@@ -148,6 +153,7 @@ class ObjectClass(SchemaElement):
     self.desc = d['DESC'][0]
     self.must = d['MUST']
     self.may = d['MAY']
+    self.x_origin = d['X-ORIGIN']
     # Default is STRUCTURAL, see RFC2552 or draft-ietf-ldapbis-syntaxes
     self.kind = 0
     if d['ABSTRACT']!=None:
@@ -159,13 +165,6 @@ class ObjectClass(SchemaElement):
       self.sup = ('top',)
     else:
       self.sup = d['SUP']
-    assert type(self.names)==TupleType
-    assert self.desc is None or type(self.desc)==StringType
-    assert type(self.obsolete)==BooleanType and (self.obsolete==0 or self.obsolete==1)
-    assert type(self.sup)==TupleType
-    assert type(self.kind)==IntType
-    assert type(self.must)==TupleType
-    assert type(self.may)==TupleType
     return
 
   def __str__(self):
@@ -177,6 +176,7 @@ class ObjectClass(SchemaElement):
     result.append({0:' STRUCTURAL',1:' ABSTRACT',2:' AUXILIARY'}[self.kind])
     result.append(self.key_list('MUST',self.must,sep=' $ '))
     result.append(self.key_list('MAY',self.may,sep=' $ '))
+    result.append(self.key_list('X-ORIGIN',self.x_origin,quoted=1))
     return '( %s )' % ''.join(result)
 
 
@@ -199,11 +199,11 @@ class AttributeType(SchemaElement):
   Class attributes:
 
   oid
-    OID assigned to the attribute type
+    OID assigned to the attribute type (string)
   names
-    This list of strings contains all NAMEs of the attribute type
+    All NAMEs of the attribute type (tuple of strings)
   desc
-    This string contains description text (DESC) of the attribute type
+    Description text (DESC) of the attribute type (string, or None if missing)
   obsolete
     Integer flag (0 or 1) indicating whether the attribute type is marked
     as OBSOLETE in the schema
@@ -211,19 +211,19 @@ class AttributeType(SchemaElement):
     Integer flag (0 or 1) indicating whether the attribute must
     have only one value
   syntax
-    String contains OID of the LDAP syntax assigned to the attribute type
+    OID of the LDAP syntax assigned to the attribute type
   no_user_mod
     Integer flag (0 or 1) indicating whether the attribute is modifiable
     by a client application
   equality
-    String contains NAME or OID of the matching rule used for
-    checking whether attribute values are equal
+    NAME or OID of the matching rule used for checking whether attribute values
+    are equal (string, or None if missing)
   substr
-    String contains NAME or OID of the matching rule used for
-    checking whether an attribute value contains another value
+    NAME or OID of the matching rule used for checking whether an attribute
+    value contains another value (string, or None if missing)
   ordering
-    String contains NAME or OID of the matching rule used for
-    checking whether attribute values are lesser-equal than
+    NAME or OID of the matching rule used for checking whether attribute values
+    are lesser-equal than (string, or None if missing)
   usage
     USAGE of an attribute type:
     0 = userApplications
@@ -231,10 +231,16 @@ class AttributeType(SchemaElement):
     2 = distributedOperation,
     3 = dSAOperation
   sup
-    This list of strings contains NAMEs or OIDs of attribute types
-    this attribute type is derived from
+    NAMEs or OIDs of attribute types this attribute type is derived from
+    (tuple of strings)
+  x_origin
+    Value of the X-ORIGIN extension flag (tuple of strings).
+
+    Although it's not official, X-ORIGIN is used in several LDAP server
+    implementations to indicate the source of the associated schema
+    element
   """
-  schema_attribute = 'attributeTypes'
+  schema_attribute = u'attributeTypes'
   token_defaults = {
     'NAME':(()),
     'DESC':(None,),
@@ -248,7 +254,7 @@ class AttributeType(SchemaElement):
     'COLLECTIVE':None,
     'NO-USER-MODIFICATION':None,
     'USAGE':('userApplications',),
-    'X-ORIGIN':(None,),
+    'X-ORIGIN':(),
     'X-ORDERED':(None,),
   }
 
@@ -260,7 +266,7 @@ class AttributeType(SchemaElement):
     self.equality = d['EQUALITY'][0]
     self.ordering = d['ORDERING'][0]
     self.substr = d['SUBSTR'][0]
-    self.x_origin = d['X-ORIGIN'][0]
+    self.x_origin = d['X-ORIGIN']
     self.x_ordered = d['X-ORDERED'][0]
     try:
       syntax = d['SYNTAX'][0]
@@ -279,21 +285,13 @@ class AttributeType(SchemaElement):
           self.syntax_len = None
           for i in l:
             if i.startswith("{") and i.endswith("}"):
-              self.syntax_len=long(i[1:-1])
+              self.syntax_len = int(i[1:-1])
         else:
-          self.syntax_len = long(syntax_len[:-1])
+          self.syntax_len = int(syntax_len[:-1])
     self.single_value = d['SINGLE-VALUE']!=None
     self.collective = d['COLLECTIVE']!=None
     self.no_user_mod = d['NO-USER-MODIFICATION']!=None
     self.usage = AttributeUsage.get(d['USAGE'][0],0)
-    assert type(self.names)==TupleType
-    assert self.desc is None or type(self.desc)==StringType
-    assert type(self.sup)==TupleType,'attribute sup has type %s' % (type(self.sup))
-    assert type(self.obsolete)==BooleanType and (self.obsolete==0 or self.obsolete==1)
-    assert type(self.single_value)==BooleanType and (self.single_value==0 or self.single_value==1)
-    assert type(self.no_user_mod)==BooleanType and (self.no_user_mod==0 or self.no_user_mod==1)
-    assert self.syntax is None or type(self.syntax)==StringType
-    assert self.syntax_len is None or type(self.syntax_len)==type(0L)
     return
 
   def __str__(self):
@@ -319,7 +317,7 @@ class AttributeType(SchemaElement):
         3:" USAGE dSAOperation",
       }[self.usage]
     )
-    result.append(self.key_attr('X-ORIGIN',self.x_origin,quoted=1))
+    result.append(self.key_list('X-ORIGIN',self.x_origin,quoted=1))
     result.append(self.key_attr('X-ORDERED',self.x_ordered,quoted=1))
     return '( %s )' % ''.join(result)
 
@@ -331,12 +329,12 @@ class LDAPSyntax(SchemaElement):
   oid
     OID assigned to the LDAP syntax
   desc
-    This string contains description text (DESC) of the LDAP syntax
+    Description text (DESC) of the LDAP syntax (string, or None if missing)
   not_human_readable
     Integer flag (0 or 1) indicating whether the attribute type is marked
     as not human-readable (X-NOT-HUMAN-READABLE)
   """
-  schema_attribute = 'ldapSyntaxes'
+  schema_attribute = u'ldapSyntaxes'
   token_defaults = {
     'DESC':(None,),
     'X-NOT-HUMAN-READABLE':(None,),
@@ -348,10 +346,9 @@ class LDAPSyntax(SchemaElement):
     self.desc = d['DESC'][0]
     self.x_subst = d['X-SUBST'][0]
     self.not_human_readable = \
-      NOT_HUMAN_READABLE_LDAP_SYNTAXES.has_key(self.oid) or \
+      self.oid in NOT_HUMAN_READABLE_LDAP_SYNTAXES or \
       d['X-NOT-HUMAN-READABLE'][0]=='TRUE'
     self.x_binary_transfer_required = d['X-BINARY-TRANSFER-REQUIRED'][0]=='TRUE'
-    assert self.desc is None or type(self.desc)==StringType
     return
 
   def __str__(self):
@@ -376,16 +373,17 @@ class MatchingRule(SchemaElement):
   oid
     OID assigned to the matching rule
   names
-    This list of strings contains all NAMEs of the matching rule
+    All NAMEs of the matching rule (tuple of strings)
   desc
-    This string contains description text (DESC) of the matching rule
+    Description text (DESC) of the matching rule
   obsolete
     Integer flag (0 or 1) indicating whether the matching rule is marked
     as OBSOLETE in the schema
   syntax
-    String contains OID of the LDAP syntax this matching rule is usable with
+    OID of the LDAP syntax this matching rule is usable with
+    (string, or None if missing)
   """
-  schema_attribute = 'matchingRules'
+  schema_attribute = u'matchingRules'
   token_defaults = {
     'NAME':(()),
     'DESC':(None,),
@@ -398,10 +396,6 @@ class MatchingRule(SchemaElement):
     self.desc = d['DESC'][0]
     self.obsolete = d['OBSOLETE']!=None
     self.syntax = d['SYNTAX'][0]
-    assert type(self.names)==TupleType
-    assert self.desc is None or type(self.desc)==StringType
-    assert type(self.obsolete)==BooleanType and (self.obsolete==0 or self.obsolete==1)
-    assert self.syntax is None or type(self.syntax)==StringType
     return
 
   def __str__(self):
@@ -425,17 +419,17 @@ class MatchingRuleUse(SchemaElement):
   oid
     OID of the accompanying matching rule
   names
-    This list of strings contains all NAMEs of the matching rule
+    All NAMEs of the matching rule (tuple of strings)
   desc
-    This string contains description text (DESC) of the matching rule
+    Description text (DESC) of the matching rule (string, or None if missing)
   obsolete
     Integer flag (0 or 1) indicating whether the matching rule is marked
     as OBSOLETE in the schema
   applies
-    This list of strings contains NAMEs or OIDs of attribute types
-    for which this matching rule is used
+    NAMEs or OIDs of attribute types for which this matching rule is used
+    (tuple of strings)
   """
-  schema_attribute = 'matchingRuleUse'
+  schema_attribute = u'matchingRuleUse'
   token_defaults = {
     'NAME':(()),
     'DESC':(None,),
@@ -448,10 +442,6 @@ class MatchingRuleUse(SchemaElement):
     self.desc = d['DESC'][0]
     self.obsolete = d['OBSOLETE']!=None
     self.applies = d['APPLIES']
-    assert type(self.names)==TupleType
-    assert self.desc is None or type(self.desc)==StringType
-    assert type(self.obsolete)==BooleanType and (self.obsolete==0 or self.obsolete==1)
-    assert type(self.applies)==TupleType
     return
 
   def __str__(self):
@@ -475,28 +465,31 @@ class DITContentRule(SchemaElement):
   oid
     OID of the accompanying structural object class
   names
-    This list of strings contains all NAMEs of the DIT content rule
+    All NAMEs of the DIT content rule (tuple of strings)
   desc
-    This string contains description text (DESC) of the DIT content rule
+    Description text (DESC) of the DIT content rule
+    (string, or None if missing)
   obsolete
     Integer flag (0 or 1) indicating whether the DIT content rule is marked
     as OBSOLETE in the schema
   aux
-    This list of strings contains NAMEs or OIDs of all auxiliary
-    object classes usable in an entry of the object class
+    NAMEs or OIDs of all auxiliary object classes usable in an entry of the
+    object class (tuple of strings)
   must
-    This list of strings contains NAMEs or OIDs of all attributes
-    an entry of the object class must have which may extend the
-    list of required attributes of the object classes of an entry
+    NAMEs or OIDs of all attributes an entry of the object class must
+    have, which may extend the list of required attributes of the object
+    classes of an entry.
+    (tuple of strings)
   may
-    This list of strings contains NAMEs or OIDs of additional attributes
-    an entry of the object class may have which may extend the
-    list of optional attributes of the object classes of an entry
+    NAMEs or OIDs of additional attributes an entry of the object class may
+    have. which may extend the list of optional attributes of the object
+    classes of an entry.
+    (tuple of strings)
   nots
-    This list of strings contains NAMEs or OIDs of attributes which
-    may not be present in an entry of the object class
+    NAMEs or OIDs of attributes which may not be present in an entry of the
+    object class. (tuple of strings)
   """
-  schema_attribute = 'dITContentRules'
+  schema_attribute = u'dITContentRules'
   token_defaults = {
     'NAME':(()),
     'DESC':(None,),
@@ -515,13 +508,6 @@ class DITContentRule(SchemaElement):
     self.must = d['MUST']
     self.may = d['MAY']
     self.nots = d['NOT']
-    assert type(self.names)==TupleType
-    assert self.desc is None or type(self.desc)==StringType
-    assert type(self.obsolete)==BooleanType and (self.obsolete==0 or self.obsolete==1)
-    assert type(self.aux)==TupleType
-    assert type(self.must)==TupleType
-    assert type(self.may)==TupleType
-    assert type(self.nots)==TupleType
     return
 
   def __str__(self):
@@ -548,19 +534,20 @@ class DITStructureRule(SchemaElement):
   ruleid
     rule ID of the DIT structure rule (only locally unique)
   names
-    This list of strings contains all NAMEs of the DIT structure rule
+    All NAMEs of the DIT structure rule (tuple of strings)
   desc
-    This string contains description text (DESC) of the DIT structure rule
+    Description text (DESC) of the DIT structure rule
+    (string, or None if missing)
   obsolete
     Integer flag (0 or 1) indicating whether the DIT content rule is marked
     as OBSOLETE in the schema
   form
-    List of strings with NAMEs or OIDs of associated name forms
+    NAMEs or OIDs of associated name forms (tuple of strings)
   sup
-    List of strings with NAMEs or OIDs of allowed structural object classes
-    of superior entries in the DIT
+    NAMEs or OIDs of allowed structural object classes
+    of superior entries in the DIT (tuple of strings)
   """
-  schema_attribute = 'dITStructureRules'
+  schema_attribute = u'dITStructureRules'
 
   token_defaults = {
     'NAME':(()),
@@ -582,11 +569,6 @@ class DITStructureRule(SchemaElement):
     self.obsolete = d['OBSOLETE']!=None
     self.form = d['FORM'][0]
     self.sup = d['SUP']
-    assert type(self.names)==TupleType
-    assert self.desc is None or type(self.desc)==StringType
-    assert type(self.obsolete)==BooleanType and (self.obsolete==0 or self.obsolete==1)
-    assert type(self.form)==StringType
-    assert type(self.sup)==TupleType
     return
 
   def __str__(self):
@@ -611,25 +593,24 @@ class NameForm(SchemaElement):
   oid
     OID of the name form
   names
-    This list of strings contains all NAMEs of the name form
+    All NAMEs of the name form (tuple of strings)
   desc
-    This string contains description text (DESC) of the name form
+    Description text (DESC) of the name form (string, or None if missing)
   obsolete
     Integer flag (0 or 1) indicating whether the name form is marked
     as OBSOLETE in the schema
   form
-    List of strings with NAMEs or OIDs of associated name forms
+    NAMEs or OIDs of associated name forms (tuple of strings)
   oc
-    String with NAME or OID of structural object classes this name form
-    is usable with
+    NAME or OID of structural object classes this name form
+    is usable with (string)
   must
-    This list of strings contains NAMEs or OIDs of all attributes
-    an RDN must contain
+    NAMEs or OIDs of all attributes an RDN must contain (tuple of strings)
   may
-    This list of strings contains NAMEs or OIDs of additional attributes
-    an RDN may contain
+    NAMEs or OIDs of additional attributes an RDN may contain
+    (tuple of strings)
   """
-  schema_attribute = 'nameForms'
+  schema_attribute = u'nameForms'
   token_defaults = {
     'NAME':(()),
     'DESC':(None,),
@@ -646,12 +627,6 @@ class NameForm(SchemaElement):
     self.oc = d['OC'][0]
     self.must = d['MUST']
     self.may = d['MAY']
-    assert type(self.names)==TupleType
-    assert self.desc is None or type(self.desc)==StringType
-    assert type(self.obsolete)==BooleanType and (self.obsolete==0 or self.obsolete==1)
-    assert type(self.oc)==StringType
-    assert type(self.must)==TupleType
-    assert type(self.may)==TupleType
     return
 
   def __str__(self):
@@ -665,7 +640,7 @@ class NameForm(SchemaElement):
     return '( %s )' % ''.join(result)
 
 
-class Entry(UserDict.UserDict):
+class Entry(IterableUserDict):
   """
   Schema-aware implementation of an LDAP entry class.
 
@@ -678,7 +653,7 @@ class Entry(UserDict.UserDict):
     self._attrtype2keytuple = {}
     self._s = schema
     self.dn = dn
-    UserDict.UserDict.__init__(self,{})
+    IterableUserDict.IterableUserDict.__init__(self,{})
     self.update(entry)
 
   def _at2key(self,nameoroid):
@@ -699,11 +674,11 @@ class Entry(UserDict.UserDict):
       return t
 
   def update(self,dict):
-    for key in dict.keys():
-      self[key] = dict[key]
+    for key, value in dict.values():
+      self[key] = value
 
-  def __contains__(self,key):
-    return self.has_key(key)
+  def __contains__(self,nameoroid):
+    return self._at2key(nameoroid) in self.data
 
   def __getitem__(self,nameoroid):
     return self.data[self._at2key(nameoroid)]
@@ -721,13 +696,7 @@ class Entry(UserDict.UserDict):
 
   def has_key(self,nameoroid):
     k = self._at2key(nameoroid)
-    return self.data.has_key(k)
-
-  def get(self,nameoroid,failobj):
-    try:
-      return self[nameoroid]
-    except KeyError:
-      return failobj
+    return k in self.data
 
   def keys(self):
     return self._keytuple2attrtype.values()
