@@ -27,13 +27,13 @@ LDAPControl_DumpList( LDAPControl** lcs ) {
 } */
 
 /* Free a single LDAPControl object created by Tuple_to_LDAPControl */
-  
+
 static void
-LDAPControl_DEL( LDAPControl* lc )
+LDAPControl_DEL(LDAPControl *lc)
 {
     if (lc == NULL)
         return;
-  
+
     if (lc->ldctl_oid)
         PyMem_DEL(lc->ldctl_oid);
     PyMem_DEL(lc);
@@ -42,16 +42,17 @@ LDAPControl_DEL( LDAPControl* lc )
 /* Free an array of LDAPControl objects created by LDAPControls_from_object */
 
 void
-LDAPControl_List_DEL( LDAPControl** lcs )
+LDAPControl_List_DEL(LDAPControl **lcs)
 {
-    LDAPControl** lcp;
+    LDAPControl **lcp;
+
     if (lcs == NULL)
         return;
 
-    for ( lcp = lcs; *lcp; lcp++ )
-        LDAPControl_DEL( *lcp );
+    for (lcp = lcs; *lcp; lcp++)
+        LDAPControl_DEL(*lcp);
 
-    PyMem_DEL( lcs );
+    PyMem_DEL(lcs);
 }
 
 /* Takes a tuple of the form:
@@ -61,8 +62,8 @@ LDAPControl_List_DEL( LDAPControl** lcs )
  * The Value string should represent an ASN.1 encoded structure.
  */
 
-static LDAPControl*
-Tuple_to_LDAPControl( PyObject* tup )
+static LDAPControl *
+Tuple_to_LDAPControl(PyObject *tup)
 {
     char *oid;
     char iscritical;
@@ -72,13 +73,14 @@ Tuple_to_LDAPControl( PyObject* tup )
     Py_ssize_t len;
 
     if (!PyTuple_Check(tup)) {
-      LDAPerror_TypeError("Tuple_to_LDAPControl(): expected a tuple", tup);
-      return NULL;
+        LDAPerror_TypeError("Tuple_to_LDAPControl(): expected a tuple", tup);
+        return NULL;
     }
 
-    if (!PyArg_ParseTuple( tup, "sbO:Tuple_to_LDAPControl", &oid, &iscritical, &bytes ))
+    if (!PyArg_ParseTuple
+        (tup, "sbO:Tuple_to_LDAPControl", &oid, &iscritical, &bytes))
         return NULL;
-  
+
     lc = PyMem_NEW(LDAPControl, 1);
     if (lc == NULL) {
         PyErr_NoMemory();
@@ -110,7 +112,7 @@ Tuple_to_LDAPControl( PyObject* tup )
         LDAPControl_DEL(lc);
         return NULL;
     }
-    
+
     lc->ldctl_value = berbytes;
 
     return lc;
@@ -120,41 +122,42 @@ Tuple_to_LDAPControl( PyObject* tup )
  * function) into an array of LDAPControl objects. */
 
 int
-LDAPControls_from_object(PyObject* list, LDAPControl ***controls_ret)
+LDAPControls_from_object(PyObject *list, LDAPControl ***controls_ret)
 {
     Py_ssize_t len, i;
-    LDAPControl** ldcs;
-    LDAPControl* ldc;
-    PyObject* item;
-  
+    LDAPControl **ldcs;
+    LDAPControl *ldc;
+    PyObject *item;
+
     if (!PySequence_Check(list)) {
-        LDAPerror_TypeError("LDAPControls_from_object(): expected a list", list);
+        LDAPerror_TypeError("LDAPControls_from_object(): expected a list",
+                            list);
         return 0;
     }
 
     len = PySequence_Length(list);
-    ldcs = PyMem_NEW(LDAPControl*, len + 1);
+    ldcs = PyMem_NEW(LDAPControl *, len + 1);
     if (ldcs == NULL) {
         PyErr_NoMemory();
         return 0;
     }
 
     for (i = 0; i < len; i++) {
-      item = PySequence_GetItem(list, i);
-      if (item == NULL) {
-          PyMem_DEL(ldcs);
-          return 0;
-      }
+        item = PySequence_GetItem(list, i);
+        if (item == NULL) {
+            PyMem_DEL(ldcs);
+            return 0;
+        }
 
-      ldc = Tuple_to_LDAPControl(item);
-      if (ldc == NULL) {
-          Py_DECREF(item);
-          PyMem_DEL(ldcs);
-          return 0;
-      }
+        ldc = Tuple_to_LDAPControl(item);
+        if (ldc == NULL) {
+            Py_DECREF(item);
+            PyMem_DEL(ldcs);
+            return 0;
+        }
 
-      ldcs[i] = ldc;
-      Py_DECREF(item);
+        ldcs[i] = ldc;
+        Py_DECREF(item);
     }
 
     ldcs[len] = NULL;
@@ -162,7 +165,7 @@ LDAPControls_from_object(PyObject* list, LDAPControl ***controls_ret)
     return 1;
 }
 
-PyObject*
+PyObject *
 LDAPControls_to_List(LDAPControl **ldcs)
 {
     PyObject *res = 0, *pyctrl;
@@ -170,7 +173,8 @@ LDAPControls_to_List(LDAPControl **ldcs)
     Py_ssize_t num_ctrls = 0, i;
 
     if (tmp)
-        while (*tmp++) num_ctrls++;
+        while (*tmp++)
+            num_ctrls++;
 
     if ((res = PyList_New(num_ctrls)) == NULL) {
         return NULL;
@@ -190,59 +194,58 @@ LDAPControls_to_List(LDAPControl **ldcs)
     return res;
 }
 
-
-
 /* --------------- en-/decoders ------------- */
 
 /* Matched Values, aka, Values Return Filter */
-static PyObject*
+static PyObject *
 encode_rfc3876(PyObject *self, PyObject *args)
 {
-	PyObject *res = 0;
-	int err;
-	BerElement *vrber = 0;
-	char *vrFilter;
-	struct berval *ctrl_val;
+    PyObject *res = 0;
+    int err;
+    BerElement *vrber = 0;
+    char *vrFilter;
+    struct berval *ctrl_val;
 
-	if (!PyArg_ParseTuple(args, "s:encode_valuesreturnfilter_control", &vrFilter)) {
-		goto endlbl;
-	}
+    if (!PyArg_ParseTuple
+        (args, "s:encode_valuesreturnfilter_control", &vrFilter)) {
+        goto endlbl;
+    }
 
-	if (!(vrber = ber_alloc_t(LBER_USE_DER))) {
-		LDAPerr(LDAP_NO_MEMORY);
-		goto endlbl;
-	}
+    if (!(vrber = ber_alloc_t(LBER_USE_DER))) {
+        LDAPerr(LDAP_NO_MEMORY);
+        goto endlbl;
+    }
 
-	err = ldap_put_vrFilter(vrber, vrFilter);
-	if (err == -1) {
-		LDAPerr(LDAP_FILTER_ERROR);
-		goto endlbl;
-	}
+    err = ldap_put_vrFilter(vrber, vrFilter);
+    if (err == -1) {
+        LDAPerr(LDAP_FILTER_ERROR);
+        goto endlbl;
+    }
 
-	err = ber_flatten(vrber, &ctrl_val);
-	if (err == -1) {
-		LDAPerr(LDAP_NO_MEMORY);
-		goto endlbl;
-	}
+    err = ber_flatten(vrber, &ctrl_val);
+    if (err == -1) {
+        LDAPerr(LDAP_NO_MEMORY);
+        goto endlbl;
+    }
 
-	res = LDAPberval_to_object(ctrl_val);
-	ber_bvfree(ctrl_val);
+    res = LDAPberval_to_object(ctrl_val);
+    ber_bvfree(ctrl_val);
 
-endlbl:
-	if (vrber)
-		ber_free(vrber, 1);
+  endlbl:
+    if (vrber)
+        ber_free(vrber, 1);
 
-	return res;
+    return res;
 }
 
-static PyObject*
+static PyObject *
 encode_rfc2696(PyObject *self, PyObject *args)
 {
     PyObject *res = 0;
     BerElement *ber = 0;
     struct berval cookie, *ctrl_val;
     Py_ssize_t cookie_len;
-    int size = 0; /* ber_int_t is int */
+    int size = 0;               /* ber_int_t is int */
     ber_tag_t tag;
 
     if (!PyArg_ParseTuple(args, "is#:encode_page_control", &size,
@@ -285,14 +288,13 @@ encode_rfc2696(PyObject *self, PyObject *args)
     res = LDAPberval_to_object(ctrl_val);
     ber_bvfree(ctrl_val);
 
- endlbl:
+  endlbl:
     if (ber)
         ber_free(ber, 1);
     return res;
 }
 
-
-static PyObject*
+static PyObject *
 decode_rfc2696(PyObject *self, PyObject *args)
 {
     PyObject *res = 0;
@@ -300,7 +302,7 @@ decode_rfc2696(PyObject *self, PyObject *args)
     struct berval ldctl_value;
     ber_tag_t tag;
     struct berval *cookiep;
-    int count = 0;  /* ber_int_t is int */
+    int count = 0;              /* ber_int_t is int */
     Py_ssize_t ldctl_value_len;
 
     if (!PyArg_ParseTuple(args, "s#:decode_page_control",
@@ -323,13 +325,13 @@ decode_rfc2696(PyObject *self, PyObject *args)
     res = Py_BuildValue("(iO&)", count, LDAPberval_to_object, cookiep);
     ber_bvfree(cookiep);
 
- endlbl:
+  endlbl:
     if (ber)
         ber_free(ber, 1);
     return res;
 }
 
-static PyObject*
+static PyObject *
 encode_assertion_control(PyObject *self, PyObject *args)
 {
     int err;
@@ -346,41 +348,35 @@ encode_assertion_control(PyObject *self, PyObject *args)
     /* XXX: ldap_create() is a nasty and slow hack. It's creating a full blown
      * LDAP object just to encode assertion controls.
      */
-    Py_BEGIN_ALLOW_THREADS
-    err = ldap_create(&ld);
-    Py_END_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS err = ldap_create(&ld);
+    Py_END_ALLOW_THREADS if (err != LDAP_SUCCESS)
+        return LDAPerror(ld, "ldap_create");
 
-    if (err != LDAP_SUCCESS)
-    	return LDAPerror(ld, "ldap_create");
-
-    err = ldap_create_assertion_control_value(ld,assertion_filterstr,&ctrl_val);
+    err =
+        ldap_create_assertion_control_value(ld, assertion_filterstr,
+                                            &ctrl_val);
 
     if (err != LDAP_SUCCESS) {
         LDAPerror(ld, "ldap_create_assertion_control_value");
-        Py_BEGIN_ALLOW_THREADS
-        ldap_unbind_ext(ld, NULL, NULL);
-        Py_END_ALLOW_THREADS
-        return NULL;
+        Py_BEGIN_ALLOW_THREADS ldap_unbind_ext(ld, NULL, NULL);
+        Py_END_ALLOW_THREADS return NULL;
     }
-    Py_BEGIN_ALLOW_THREADS
-    ldap_unbind_ext(ld, NULL, NULL);
-    Py_END_ALLOW_THREADS
-
-    res = LDAPberval_to_object(&ctrl_val);
+    Py_BEGIN_ALLOW_THREADS ldap_unbind_ext(ld, NULL, NULL);
+    Py_END_ALLOW_THREADS res = LDAPberval_to_object(&ctrl_val);
     if (ctrl_val.bv_val != NULL) {
         ber_memfree(ctrl_val.bv_val);
     }
-    endlbl:
+  endlbl:
 
     return res;
 }
 
 static PyMethodDef methods[] = {
-    {"encode_page_control", encode_rfc2696, METH_VARARGS },
-    {"decode_page_control", decode_rfc2696, METH_VARARGS },
-    {"encode_valuesreturnfilter_control", encode_rfc3876, METH_VARARGS },
-    {"encode_assertion_control", encode_assertion_control, METH_VARARGS },
-    { NULL, NULL }
+    {"encode_page_control", encode_rfc2696, METH_VARARGS},
+    {"decode_page_control", decode_rfc2696, METH_VARARGS},
+    {"encode_valuesreturnfilter_control", encode_rfc3876, METH_VARARGS},
+    {"encode_assertion_control", encode_assertion_control, METH_VARARGS},
+    {NULL, NULL}
 };
 
 void
