@@ -30,12 +30,14 @@ class TestCidict(unittest.TestCase):
         cix = ldap.cidict.cidict(data)
         self.assertEqual(cix["ABCDEF"], 123)
         self.assertEqual(cix.get("ABCDEF", None), 123)
-        self.assertEqual(cix.get("not existent", None), None)
+        self.assertIsNone(cix.get("not existent", None))
         cix["xYZ"] = 987
         self.assertEqual(cix["XyZ"], 987)
         self.assertEqual(cix.get("xyz", None), 987)
         cix_keys = sorted(cix.keys())
         self.assertEqual(cix_keys, ['AbCDeF','xYZ'])
+        cix_keys = sorted(cix)
+        self.assertEqual(cix_keys, ['AbCDeF','xYZ'])
         cix_items = sorted(cix.items())
         self.assertEqual(cix_items, [('AbCDeF',123), ('xYZ',987)])
         del cix["abcdEF"]
