@@ -3,14 +3,14 @@
 Automatic tests for python-ldap's module ldap.filter
 
 See https://www.python-ldap.org/ for details.
-
-$Id: t_ldap_filter.py,v 1.5 2017/09/04 07:47:29 stroeder Exp $
 """
 
-# from Python's standard lib
+import os
 import unittest
 
-# from python-ldap
+# Switch off processing .ldaprc or ldap.conf before importing _ldap
+os.environ['LDAPNOINIT'] = '1'
+
 from ldap.filter import escape_filter_chars
 
 
