@@ -3,12 +3,14 @@
 Automatic tests for python-ldap's module ldap.schema.tokenizer
 
 See https://www.python-ldap.org/ for details.
-
-$Id: t_ldap_schema_tokenizer.py,v 1.11 2017/08/15 16:21:59 stroeder Exp $
 """
 
+import os
 import unittest
 
+# Switch off processing .ldaprc or ldap.conf before importing _ldap
+os.environ['LDAPNOINIT'] = '1'
+
 import ldap.schema
 
 # basic test cases
