@@ -2,17 +2,19 @@
 """
 Automatic tests for python-ldap's module ldap.syncrepl
 
-See http://www.python-ldap.org/ for details.
-
-$Id: t_ldap_syncrepl.py,v 1.1 2017/11/20 11:42:19 stroeder Exp $
+See https://www.python-ldap.org/ for details.
 """
 
 
 import os
-import unittest
 import shelve
+import sys
+import unittest
 
-from slapdtest import SlapdObject, SlapdTestCase
+if sys.version_info[0] <= 2:
+    PY2 = True
+else:
+    PY2 = False
 
 # Switch off processing .ldaprc or ldap.conf before importing _ldap
 os.environ['LDAPNOINIT'] = '1'
@@ -21,6 +23,8 @@ import ldap
 from ldap.ldapobject import SimpleLDAPObject
 from ldap.syncrepl import SyncreplConsumer
 
+from slapdtest import SlapdObject, SlapdTestCase
+
 # a template string for generating simple slapd.conf file
 SLAPD_CONF_PROVIDER_TEMPLATE = r"""
 serverID %(serverid)s
@@ -83,34 +87,34 @@ cn: Foo4
 # NOTE: For the dict, it needs to be kept up-to-date as we make changes!
 LDAP_ENTRIES = {
     'ou=Container,dc=slapd-test,dc=python-ldap,dc=org': {
-        'objectClass': ['organizationalUnit'],
-        'ou': ['Container']
+        'objectClass': [b'organizationalUnit'],
+        'ou': [b'Container']
     },
     'cn=Foo2,dc=slapd-test,dc=python-ldap,dc=org': {
-        'objectClass': ['organizationalRole'],
-        'cn': ['Foo2']
+        'objectClass': [b'organizationalRole'],
+        'cn': [b'Foo2']
     },
     'cn=Foo4,ou=Container,dc=slapd-test,dc=python-ldap,dc=org': {
-        'objectClass': ['organizationalRole'],
-        'cn': ['Foo4']
+        'objectClass': [b'organizationalRole'],
+        'cn': [b'Foo4']
     },
     'cn=Manager,dc=slapd-test,dc=python-ldap,dc=org': {
-        'objectClass': ['applicationProcess', 'simpleSecurityObject'],
-        'userPassword': ['password'],
-        'cn': ['Manager']
+        'objectClass': [b'applicationProcess', b'simpleSecurityObject'],
+        'userPassword': [b'password'],
+        'cn': [b'Manager']
     },
     'cn=Foo3,dc=slapd-test,dc=python-ldap,dc=org': {
-        'objectClass': ['organizationalRole'],
-        'cn': ['Foo3']
+        'objectClass': [b'organizationalRole'],
+        'cn': [b'Foo3']
     },
     'cn=Foo1,dc=slapd-test,dc=python-ldap,dc=org': {
-        'objectClass': ['organizationalRole'],
-        'cn': ['Foo1']
+        'objectClass': [b'organizationalRole'],
+        'cn': [b'Foo1']
     },
     'dc=slapd-test,dc=python-ldap,dc=org': {
-        'objectClass': ['dcObject', 'organization'],
-        'dc': ['slapd-test'],
-        'o': ['slapd-test']
+        'objectClass': [b'dcObject', b'organization'],
+        'dc': [b'slapd-test'],
+        'o': [b'slapd-test']
     }
 }
 
@@ -127,9 +131,8 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
     Needs to be separate, because once an LDAP client starts a syncrepl
     search, it can't be used for anything else.
     """
-    server_class = SyncreplProvider
 
-    def __init__(self, uri, dn, password, storage=None):
+    def __init__(self, uri, dn, password, storage=None, **kwargs):
         """
         Set up our object by creating a search client, connecting, and binding.
         """
@@ -149,10 +152,9 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
         self.present = []
         self.refresh_done = False
 
-        SimpleLDAPObject.__init__(self, uri)
+        SimpleLDAPObject.__init__(self, uri, **kwargs)
         self.simple_bind_s(dn, password)
 
-
     def unbind_s(self):
         """
         In addition to unbinding from LDAP, we need to close the shelf.
@@ -163,7 +165,6 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
             self.dn_attrs.close()
         SimpleLDAPObject.unbind_s(self)
 
-
     def search(self, search_base, search_mode):
         """
         Start a syncrepl search operation, given a base DN and search mode.
@@ -172,17 +173,14 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
             search_base,
             ldap.SCOPE_SUBTREE,
             mode=search_mode,
-            filterstr='(objectClass=*)'
         )
 
-
     def cancel(self):
         """
         A simple wrapper to call parent class with syncrepl search ID.
         """
         SimpleLDAPObject.cancel(self, self.search_id)
 
-
     def poll(self, timeout=None, all=0):
         """
         Take the params, add the syncrepl search ID, and call the proper poll.
@@ -193,28 +191,24 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
             all=all
         )
 
-
     def syncrepl_get_cookie(self):
         """
         Pull cookie from storage, if one exists.
         """
         return self.data['cookie']
 
-
     def syncrepl_set_cookie(self, cookie):
         """
         Update stored cookie.
         """
         self.data['cookie'] = cookie
 
-
     def syncrepl_refreshdone(self):
         """
         Just update a variable.
         """
         self.refresh_done = True
 
-
     def syncrepl_delete(self, uuids):
         """
         Delete the given items from both maps.
@@ -223,7 +217,6 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
             del self.dn_attrs[self.uuid_dn[uuid]]
             del self.uuid_dn[uuid]
 
-
     def syncrepl_entry(self, dn, attrs, uuid):
         """
         Handles adds and changes (including DN changes).
@@ -238,18 +231,17 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
         self.uuid_dn[uuid] = dn
         self.dn_attrs[dn] = attrs
 
-
     def syncrepl_present(self, uuids, refreshDeletes=False):
         """
         The 'present' message from the LDAP server is the most complicated
         part of the refresh phase.  Suggest looking here for more info:
-        http://syncrepl-client.readthedocs.io/en/latest/client.html
+        https://syncrepl-client.readthedocs.io/en/latest/client.html
         """
         if (uuids is not None) and (refreshDeletes is False):
             self.present.extend(uuids)
 
         elif (uuids is None) and (refreshDeletes is False):
-            deleted_uuids = list()
+            deleted_uuids = []
             for uuid in self.uuid_dn.keys():
                 if uuid not in self.present:
                     deleted_uuids.append(uuid)
@@ -264,7 +256,7 @@ class SyncreplClient(SimpleLDAPObject, SyncreplConsumer):
             pass
 
 
-class Test00_Syncrepl(SlapdTestCase):
+class BaseSyncreplTests(object):
     """
     This is a test of all the basic Syncrepl operations.  It covers starting a
     search (both types of search), doing the refresh part of the search,
@@ -277,7 +269,7 @@ class Test00_Syncrepl(SlapdTestCase):
 
     @classmethod
     def setUpClass(cls):
-        super(Test00_Syncrepl, cls).setUpClass()
+        super(BaseSyncreplTests, cls).setUpClass()
         # insert some Foo* objects via ldapadd
         cls.server.ldapadd(
             LDIF_TEMPLATE % {
@@ -289,57 +281,39 @@ class Test00_Syncrepl(SlapdTestCase):
             }
         )
 
-
     def setUp(self):
-        try:
-            self._ldap_conn
-        except AttributeError:
-            # open local LDAP connection
-            self._ldap_conn = self._open_ldap_conn()
-
+        super(BaseSyncreplTests, self).setUp()
+        self.tester = None
+        self.suffix = None
 
     def tearDown(self):
         self.tester.unbind_s()
+        super(BaseSyncreplTests, self).tearDown()
 
+    def create_client(self):
+        raise NotImplementedError
 
     def test_refreshOnly_search(self):
         '''
         Test to see if we can initialize a syncrepl search.
         '''
-        self.tester = SyncreplClient(
-            self.server.ldap_uri,
-            self.server.root_dn,
-            self.server.root_pw
-        )
         self.tester.search(
-            self.server.suffix,
+            self.suffix,
             'refreshOnly'
         )
 
-
     def test_refreshAndPersist_search(self):
-        self.tester = SyncreplClient(
-            self.server.ldap_uri,
-            self.server.root_dn,
-            self.server.root_pw
-        )
         self.tester.search(
-            self.server.suffix,
+            self.suffix,
             'refreshAndPersist'
         )
 
-
     def test_refreshOnly_poll_full(self):
         """
         Test doing a full refresh cycle, and check what we got.
         """
-        self.tester = SyncreplClient(
-            self.server.ldap_uri,
-            self.server.root_dn,
-            self.server.root_pw
-        )
         self.tester.search(
-            self.server.suffix,
+            self.suffix,
             'refreshOnly'
         )
         poll_result = self.tester.poll(
@@ -347,20 +321,14 @@ class Test00_Syncrepl(SlapdTestCase):
             timeout=None
         )
         self.assertFalse(poll_result)
-        self.assertEquals(self.tester.dn_attrs, LDAP_ENTRIES)
-
+        self.assertEqual(self.tester.dn_attrs, LDAP_ENTRIES)
 
     def test_refreshAndPersist_poll_only(self):
         """
         Test the refresh part of refresh-and-persist, and check what we got.
         """
-        self.tester = SyncreplClient(
-            self.server.ldap_uri,
-            self.server.root_dn,
-            self.server.root_pw
-        )
         self.tester.search(
-            self.server.suffix,
+            self.suffix,
             'refreshAndPersist'
         )
 
@@ -372,20 +340,14 @@ class Test00_Syncrepl(SlapdTestCase):
             )
             self.assertTrue(poll_result)
 
-        self.assertEquals(self.tester.dn_attrs, LDAP_ENTRIES)
-
+        self.assertEqual(self.tester.dn_attrs, LDAP_ENTRIES)
 
     def test_refreshAndPersist_timeout(self):
         """
         Make sure refreshAndPersist can handle a search with timeouts.
         """
-        self.tester = SyncreplClient(
-            self.server.ldap_uri,
-            self.server.root_dn,
-            self.server.root_pw
-        )
         self.tester.search(
-            self.server.suffix,
+            self.suffix,
             'refreshAndPersist'
         )
 
@@ -398,7 +360,7 @@ class Test00_Syncrepl(SlapdTestCase):
             self.assertTrue(poll_result)
 
         # Again, server data should not have changed.
-        self.assertEquals(self.tester.dn_attrs, LDAP_ENTRIES)
+        self.assertEqual(self.tester.dn_attrs, LDAP_ENTRIES)
 
         # Run a search with timeout.
         # Nothing is changing the server, so it shoud timeout.
@@ -409,18 +371,12 @@ class Test00_Syncrepl(SlapdTestCase):
             timeout=1
         )
 
-
     def test_refreshAndPersist_cancelled(self):
         """
         Make sure refreshAndPersist can handle cancelling a syncrepl search.
         """
-        self.tester = SyncreplClient(
-            self.server.ldap_uri,
-            self.server.root_dn,
-            self.server.root_pw
-        )
         self.tester.search(
-            self.server.suffix,
+            self.suffix,
             'refreshAndPersist'
         )
 
@@ -433,7 +389,7 @@ class Test00_Syncrepl(SlapdTestCase):
             self.assertTrue(poll_result)
 
         # Again, server data should not have changed.
-        self.assertEquals(self.tester.dn_attrs, LDAP_ENTRIES)
+        self.assertEqual(self.tester.dn_attrs, LDAP_ENTRIES)
 
         # Request cancellation.
         self.tester.cancel()
@@ -447,7 +403,7 @@ class Test00_Syncrepl(SlapdTestCase):
         )
 
         # Server data should still be intact.
-        self.assertEquals(self.tester.dn_attrs, LDAP_ENTRIES)
+        self.assertEqual(self.tester.dn_attrs, LDAP_ENTRIES)
 
 
     # TODO:
@@ -465,5 +421,30 @@ class Test00_Syncrepl(SlapdTestCase):
     # should pick it up during the persist phase.
 
 
+class TestSyncrepl(BaseSyncreplTests, SlapdTestCase):
+    def setUp(self):
+        super(TestSyncrepl, self).setUp()
+        self.tester = SyncreplClient(
+            self.server.ldap_uri,
+            self.server.root_dn,
+            self.server.root_pw,
+            bytes_mode=False
+        )
+        self.suffix = self.server.suffix
+
+
+@unittest.skipUnless(PY2, "no bytes_mode under Py3")
+class TestSyncreplBytesMode(BaseSyncreplTests, SlapdTestCase):
+    def setUp(self):
+        super(TestSyncreplBytesMode, self).setUp()
+        self.tester = SyncreplClient(
+            self.server.ldap_uri,
+            self.server.root_dn.encode('utf-8'),
+            self.server.root_pw.encode('utf-8'),
+            bytes_mode=True
+        )
+        self.suffix = self.server.suffix.encode('utf-8')
+
+
 if __name__ == '__main__':
     unittest.main()
